@@ -4,7 +4,7 @@
 modname = 'narval'
 distname = 'narval'
 
-numversion = (3, 0, 6)
+numversion = (3, 1, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -13,7 +13,8 @@ web = 'http://www.cubicweb.org/project/cubicweb-narval'
 author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
 
-__depends__ =  {'cubicweb': '>= 3.10.0'}
+__depends__ =  {'cubicweb': '>= 3.14.0',
+                'cubicweb-localperms': None}
 __recommends__ = {}
 
 
